@@ -1,8 +1,8 @@
 import sys
 import json
 
-sys.path.append("./")
-from communication import getAPIRequest
+#sys.path.append("./")
+from communication import getAPIRequest  
 
 def getAgentList():
     return getAPIRequest("/api/v2/agents")
